==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicPopupMenuSeparatorUI.h <==
// public class javax.swing.plaf.basic.BasicPopupMenuSeparatorUI

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 9693afb0713a235 javax_swing_plaf_SeparatorUI
// @dep_class 836558a1fe96dca2 javax_swing_plaf_basic_BasicPopupMenuSeparatorUI
// @dep_class eaf5c562f9f773df javax_swing_plaf_basic_BasicSeparatorUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSeparatorUI

#include "javax/swing/plaf/basic/BasicSeparatorUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *);

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$getPreferredSize$c70d4f812111358c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method_info$getPreferredSize$c70d4f812111358c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method_info$paint$772d1272d1c3f8bb;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *);

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$c70d4f812111358c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *);
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SeparatorUI$vmethods	javax_swing_plaf_SeparatorUI;
	_jc_javax_swing_plaf_basic_BasicSeparatorUI$vmethods	javax_swing_plaf_basic_BasicSeparatorUI;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_refs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_nonrefs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuSeparatorUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicPopupMenuSeparatorUI.h <==
// public class javax.swing.plaf.basic.BasicPopupMenuSeparatorUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 9693afb0713a235 javax_swing_plaf_SeparatorUI
// @dep_class 836558a1fe96dca2 javax_swing_plaf_basic_BasicPopupMenuSeparatorUI
// @dep_class eaf5c562f9f773df javax_swing_plaf_basic_BasicSeparatorUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSeparatorUI

#include "javax/swing/plaf/basic/BasicSeparatorUI.h"

#ifndef _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_
#define _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_

// Forward structure declarations
struct _jc_java_awt_Dimension$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object;

typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Dimension$object *_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$getPreferredSize$c70d4f812111358c(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$paint$772d1272d1c3f8bb(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method_info$getPreferredSize$c70d4f812111358c;
extern _jc_method _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method_info$paint$772d1272d1c3f8bb;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods {
	struct _jc_java_awt_Dimension$object	*(*getPreferredSize$c70d4f812111358c)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
	void	(*paint$772d1272d1c3f8bb)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object *, struct _jc_java_awt_Graphics$object *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SeparatorUI$vmethods	javax_swing_plaf_SeparatorUI;
	_jc_javax_swing_plaf_basic_BasicSeparatorUI$vmethods	javax_swing_plaf_basic_BasicSeparatorUI;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vmethods	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs {
    _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_refs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_refs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SeparatorUI$sub_nonrefs	javax_swing_plaf_SeparatorUI;
    _jc_javax_swing_plaf_basic_BasicSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicSeparatorUI;
    _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$sub_nonrefs	javax_swing_plaf_basic_BasicPopupMenuSeparatorUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$object {
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$vtype _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicPopupMenuSeparatorUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicPopupMenuSeparatorUI_H_ */
